@@ -29,7 +29,7 @@ from .core import (
     EvaluationConfiguration,
     ResourceContainer,
     ExtendedRequestException,
-    TextanalysisMode
+    TextanalysisMode,
 )
 
 __all__ = [
@@ -44,5 +44,5 @@ __all__ = [
     "Process",
     "ResourceContainer",
     "ExtendedRequestException",
-    "TextanalysisMode"
+    "TextanalysisMode",
 ]
