@@ -33,6 +33,8 @@ from ._rest_client import (
     Pear,
     Process,
     EvaluationConfiguration,
+    ExtendedRequestException,
+    TextanalysisMode,
     DOCUMENT_IMPORTER_CAS,
     DOCUMENT_IMPORTER_SOLR,
     DOCUMENT_IMPORTER_TEXT,
@@ -57,6 +59,7 @@ from ._rest_client import (
 __all__ = [
     "OperationNotSupported",
     "OperationTimeoutError",
+    "ExtendedRequestException",
     "ResourceContainer",
     "Terminology",
     "Client",
@@ -67,6 +70,7 @@ __all__ = [
     "Pear",
     "Process",
     "EvaluationConfiguration",
+    "TextanalysisMode",
     "DOCUMENT_IMPORTER_CAS",
     "DOCUMENT_IMPORTER_SOLR",
     "DOCUMENT_IMPORTER_TEXT",
